# ----------------------------------------------------------------------------
# Copyright (c) 2017 Semiconductor Components Industries, LLC (d/b/a
# ON Semiconductor), All Rights Reserved
#
# This code is the property of ON Semiconductor and may not be redistributed
# in any form without prior written permission from ON Semiconductor.
# The terms of use and warranty for this code are covered by contractual
# agreements between ON Semiconductor and the licensee.
#
# This is Reusable Code.
#
# -----------------------------------------------------------------------------
#

from subprocess import PIPE, Popen
from PipeReader import PipeReader

class Process(object):
    '''
    Class wraps an OS process and provides an easy interface to the input,
    output and error streams
    '''

    def __init__(self, command):
        '''
        Constructor takes the command to excecute, starts a process to allow
        communication with the streams and initialsies the readers
        '''
        self.executable = command
        self.process = Popen(command, stdin = PIPE, stdout = PIPE, stderr = PIPE, bufsize = 1)
        self.outReader = PipeReader(self.process.stdout)
        self.errReader = PipeReader(self.process.stderr)
        
    def start(self):
        '''
        Start the stdout and stderr readers
        '''
        self.outReader.start()
        self.errReader.start()
    
    def stop(self):
        '''
        stop the subprocess
        '''
        self.process.stdin.close()
    
    def isAlive(self):
        '''
        Report if the process is still running
        '''
        return self.outReader.is_alive() and self.errReader.is_alive()
    
    def canRead(self):
        '''
        report of we can read from the process
        '''
        return self.outReader.canRead() or self.errReader.canRead()
    
    def readline(self):
        '''
        Read a line of output from either the stdout or stderr, note that this
        arbitrarily gives precedence to stdout, so some error messages will seem
        to appear late in the combined text 
        '''
        if self.outReader.canRead():
            return self.outReader.readLine()
        if self.errReader.canRead():
            return self.errReader.readLine()
        return None
        
    def send(self, command):
        '''
        Write a command to the process stdin
        '''
        if self.isAlive():
            self.process.stdin.write("%s\n" % command)
            self.process.stdin.flush()
            
