# ----------------------------------------------------------------------------
# Copyright (c) 2017 Semiconductor Components Industries, LLC (d/b/a
# ON Semiconductor), All Rights Reserved
#
# This code is the property of ON Semiconductor and may not be redistributed
# in any form without prior written permission from ON Semiconductor.
# The terms of use and warranty for this code are covered by contractual
# agreements between ON Semiconductor and the licensee.
#
# This is Reusable Code.
#
# -----------------------------------------------------------------------------
#

class DSPSegmentKey(object):
    '''
    Defines a segment key that can be used in dicts
    '''
    
    def __init__(self, hdr, data):
        '''
        Constructor which takes an ELFFile header object and the data associated
        with the segment
        '''
        self.offset = hdr.p_offset
        self.type = hdr.p_type
        self.filesz = hdr.p_filesz
        self.memsz = hdr.p_memsz
        self.paddr = hdr.p_paddr
        self.vaddr = hdr.p_vaddr
        self.data = data
        
    def _important(self):
        ''' retrieve the important fields from the key '''
        # Important is defined as the set of fields that are used by the
        # memory integrator to identify the segment in header and source files 
        return (self.offset, self.type, self.filesz, self.memsz, self.paddr, self.vaddr)
    
    def __hash__(self):
        '''
        Standard hashing function, only needs to consider the important fields
        '''
        return hash(self._important())

    def __eq__(self, other):
        '''
        Equality only needs to consider the important fields
        '''
        return self._important() == other._important()

    def __ne__(self, other):
        ''' This is not the equal above '''
        return not (self == other)
    
    def __repr__(self):
        ''' provide a standard representation of the important stuff '''
        return "0x%08x %8s %8d %8d 0x%08x 0x%08x" % self._important()
    
        
