# ----------------------------------------------------------------------------
# Copyright (c) 2017 Semiconductor Components Industries, LLC (d/b/a
# ON Semiconductor), All Rights Reserved
#
# This code is the property of ON Semiconductor and may not be redistributed
# in any form without prior written permission from ON Semiconductor.
# The terms of use and warranty for this code are covered by contractual
# agreements between ON Semiconductor and the licensee.
#
# This is Reusable Code.
#
# -----------------------------------------------------------------------------
#

from argparse import ArgumentParser, FileType
from DSPIntegrator import DSPIntegrator

if __name__ == '__main__':

    # Create a parser for the integrator.
    #
    #    --elf <file>
    #        This defines the elf file to be processed. This will naturally be
    #        the output from the Synopsys Chess compiler, and that is normally
    #        found in the release folder of the Chess project
    #    --symbols <file>
    #        This refers to a symbol definition file in JSON format, which
    #        specifies symbols which should be identified within the ELF
    #        file and provided for use by the CM3 C code. This feature
    #        is not currently used by the Codec framework but is provided
    #        for reference.
    #    --output <folder>
    #        This specifies the folder to which the output files will be written
    #    --tag <identifier>
    #        This allows the specification of a tag that will be included in
    #        all the generated filenames and data structures so that the
    #        generated code is easily differentiated from other modules.
    #    --v1
    #        This flag is provided for backwards compatibility with older
    #        synopsys tools which generated slightly different ELF binary
    #        format files. Current tools should not require the use of this.
    #
    parser = ArgumentParser(description = 'RSL10 DSP Integration')
    parser.add_argument('-e', '--elf', type=FileType('rb'), metavar='<elf file>', required=True, help='Defines the ELF file to be processed')
    parser.add_argument('-s', '--symbols', type=FileType('r'), metavar='<config file>', help='Configuration file specifying symbols to be included')
    parser.add_argument('-o', '--output', metavar='<folder>', help='Output folder to which the files will be written', default='.')
    parser.add_argument('-t', '--tag', metavar='<identifier>', help='Tag to identify the generated data objects')
    parser.add_argument('-x', '--v1', default=False, action='store_true')
    
    args = parser.parse_args()

    # we used the argument parser to ensure the files are available but
    # we really want to control access ourselves, so close the open file handles   
    args.elf.close()
    if args.symbols:
        args.symbols.close()
    
    # Create an integrator object and tell it to parse the specified parameters.
    #   
    integrator = DSPIntegrator(args.elf, args.output, args.tag, args.symbols, args.v1)
    integrator.parse()
    